==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Block/ts/Block_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Block</name>
    <message>
        <location filename="../Block.js" line="+67"/>
        <source>Block Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show block tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Block</source>
        <translatorcomment>--exact match--
--file: qcad_pl.ts--
&amp;Blok</translatorcomment>
        <translation type="unfinished">&amp;Blok</translation>
    </message>
</context>
<context>
    <name>BlockDialog</name>
    <message>
        <location filename="../BlockDialog.js" line="+115"/>
        <source>Leading or trailing spaces.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is empty.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Nazwa bloku jest pusty.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is invalid.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Block &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block already exists.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Blok już istnieje.</translation>
    </message>
    <message>
        <location filename="../BlockDialog.ui" line="+17"/>
        <source>Block Data</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Blok danych</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Block name:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Nazwa bloku:</translatorcomment>
        <translation type="unfinished">Nazwa bloku:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>block 1</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Blok 1</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Block/ts/Block_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Block</name>
    <message>
        <location filename="../Block.js" line="+67"/>
        <source>Block Tools</source>
        <translation>Narzędzia bloku</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show block tools</source>
        <translation>Wyświetla narzędzia bloku</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Block</source>
        <translatorcomment>--exact match--
--file: qcad_pl.ts--
&amp;Blok</translatorcomment>
        <translation>&amp;Blok</translation>
    </message>
</context>
<context>
    <name>BlockDialog</name>
    <message>
        <location filename="../BlockDialog.js" line="+134"/>
        <source>Leading or trailing spaces.</source>
        <translation>Poprzedzające lub końcowe odstępy.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is empty.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Nazwa bloku jest pusta.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is invalid.</source>
        <translation>Nazwa bloku jest nieprawidłowa.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Block &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation>Blok „%1” już istnieje&lt;br&gt;i zostanie zastąpiony.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block already exists.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Blok już istnieje.</translation>
    </message>
    <message>
        <location filename="../BlockDialog.ui" line="+17"/>
        <source>Block Data</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Dane bloku</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Block name:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Nazwa bloku:</translatorcomment>
        <translation>Nazwa bloku:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>block 1</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Blok 1</translation>
    </message>
</context>
</TS>
